==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/elasticsearch/kotlin/inputs/DomainSamlOptionsSamlOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.elasticsearch.kotlin.inputs

import com.pulumi.aws.elasticsearch.inputs.DomainSamlOptionsSamlOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property enabled Whether SAML authentication is enabled.
 * @property idp Information from your identity provider.
 * @property masterBackendRole This backend role from the SAML IdP receives full permissions to the cluster, equivalent to a new master user.
 * @property masterUserName This username from the SAML IdP receives full permissions to the cluster, equivalent to a new master user.
 * @property rolesKey Element of the SAML assertion to use for backend roles. Default is roles.
 * @property sessionTimeoutMinutes Duration of a session in minutes after a user logs in. Default is 60. Maximum value is 1,440.
 * @property subjectKey Custom SAML attribute to use for user names. Default is an empty string - `""`. This will cause Elasticsearch to use the `NameID` element of the `Subject`, which is the default location for name identifiers in the SAML specification.
 */
public data class DomainSamlOptionsSamlOptionsArgs(
    public val enabled: Output<Boolean>? = null,
    public val idp: Output<DomainSamlOptionsSamlOptionsIdpArgs>? = null,
    public val masterBackendRole: Output<String>? = null,
    public val masterUserName: Output<String>? = null,
    public val rolesKey: Output<String>? = null,
    public val sessionTimeoutMinutes: Output<Int>? = null,
    public val subjectKey: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.elasticsearch.inputs.DomainSamlOptionsSamlOptionsArgs> {
    override fun toJava(): com.pulumi.aws.elasticsearch.inputs.DomainSamlOptionsSamlOptionsArgs =
        com.pulumi.aws.elasticsearch.inputs.DomainSamlOptionsSamlOptionsArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .idp(idp?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .masterBackendRole(masterBackendRole?.applyValue({ args0 -> args0 }))
            .masterUserName(masterUserName?.applyValue({ args0 -> args0 }))
            .rolesKey(rolesKey?.applyValue({ args0 -> args0 }))
            .sessionTimeoutMinutes(sessionTimeoutMinutes?.applyValue({ args0 -> args0 }))
            .subjectKey(subjectKey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DomainSamlOptionsSamlOptionsArgs].
 */
@PulumiTagMarker
public class DomainSamlOptionsSamlOptionsArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var idp: Output<DomainSamlOptionsSamlOptionsIdpArgs>? = null

    private var masterBackendRole: Output<String>? = null

    private var masterUserName: Output<String>? = null

    private var rolesKey: Output<String>? = null

    private var sessionTimeoutMinutes: Output<Int>? = null

    private var subjectKey: Output<String>? = null

    /**
     * @param value Whether SAML authentication is enabled.
     */
    @JvmName("hvgrarpypdgtijcl")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Information from your identity provider.
     */
    @JvmName("gtkdbhgtkmxdtcvi")
    public suspend fun idp(`value`: Output<DomainSamlOptionsSamlOptionsIdpArgs>) {
        this.idp = value
    }

    /**
     * @param value This backend role from the SAML IdP receives full permissions to the cluster, equivalent to a new master user.
     */
    @JvmName("gcngcatnfmlnmqov")
    public suspend fun masterBackendRole(`value`: Output<String>) {
        this.masterBackendRole = value
    }

    /**
     * @param value This username from the SAML IdP receives full permissions to the cluster, equivalent to a new master user.
     */
    @JvmName("sptdurxwnnbqkkor")
    public suspend fun masterUserName(`value`: Output<String>) {
        this.masterUserName = value
    }

    /**
     * @param value Element of the SAML assertion to use for backend roles. Default is roles.
     */
    @JvmName("wlojbeconrjajrwa")
    public suspend fun rolesKey(`value`: Output<String>) {
        this.rolesKey = value
    }

    /**
     * @param value Duration of a session in minutes after a user logs in. Default is 60. Maximum value is 1,440.
     */
    @JvmName("qhyomvkjqscngwfj")
    public suspend fun sessionTimeoutMinutes(`value`: Output<Int>) {
        this.sessionTimeoutMinutes = value
    }

    /**
     * @param value Custom SAML attribute to use for user names. Default is an empty string - `""`. This will cause Elasticsearch to use the `NameID` element of the `Subject`, which is the default location for name identifiers in the SAML specification.
     */
    @JvmName("mlpkkucqkjjwfies")
    public suspend fun subjectKey(`value`: Output<String>) {
        this.subjectKey = value
    }

    /**
     * @param value Whether SAML authentication is enabled.
     */
    @JvmName("aimcshteaaxirexv")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Information from your identity provider.
     */
    @JvmName("upnqpuhbgtptsopg")
    public suspend fun idp(`value`: DomainSamlOptionsSamlOptionsIdpArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.idp = mapped
    }

    /**
     * @param argument Information from your identity provider.
     */
    @JvmName("momhlchjaicorrgy")
    public suspend fun idp(argument: suspend DomainSamlOptionsSamlOptionsIdpArgsBuilder.() -> Unit) {
        val toBeMapped = DomainSamlOptionsSamlOptionsIdpArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.idp = mapped
    }

    /**
     * @param value This backend role from the SAML IdP receives full permissions to the cluster, equivalent to a new master user.
     */
    @JvmName("tkmvsnlltayfsbhh")
    public suspend fun masterBackendRole(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.masterBackendRole = mapped
    }

    /**
     * @param value This username from the SAML IdP receives full permissions to the cluster, equivalent to a new master user.
     */
    @JvmName("ctlhqjtulfblhvbg")
    public suspend fun masterUserName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.masterUserName = mapped
    }

    /**
     * @param value Element of the SAML assertion to use for backend roles. Default is roles.
     */
    @JvmName("rbvxiyffhsbvrikb")
    public suspend fun rolesKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rolesKey = mapped
    }

    /**
     * @param value Duration of a session in minutes after a user logs in. Default is 60. Maximum value is 1,440.
     */
    @JvmName("eipgxceqinwqmmau")
    public suspend fun sessionTimeoutMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sessionTimeoutMinutes = mapped
    }

    /**
     * @param value Custom SAML attribute to use for user names. Default is an empty string - `""`. This will cause Elasticsearch to use the `NameID` element of the `Subject`, which is the default location for name identifiers in the SAML specification.
     */
    @JvmName("tgixiugsnnrwfkle")
    public suspend fun subjectKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subjectKey = mapped
    }

    internal fun build(): DomainSamlOptionsSamlOptionsArgs = DomainSamlOptionsSamlOptionsArgs(
        enabled = enabled,
        idp = idp,
        masterBackendRole = masterBackendRole,
        masterUserName = masterUserName,
        rolesKey = rolesKey,
        sessionTimeoutMinutes = sessionTimeoutMinutes,
        subjectKey = subjectKey,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/elasticsearch/kotlin/inputs/DomainSamlOptionsSamlOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.elasticsearch.kotlin.inputs

import com.pulumi.aws.elasticsearch.inputs.DomainSamlOptionsSamlOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property enabled Whether SAML authentication is enabled.
 * @property idp Information from your identity provider.
 * @property masterBackendRole This backend role from the SAML IdP receives full permissions to the cluster, equivalent to a new master user.
 * @property masterUserName This username from the SAML IdP receives full permissions to the cluster, equivalent to a new master user.
 * @property rolesKey Element of the SAML assertion to use for backend roles. Default is roles.
 * @property sessionTimeoutMinutes Duration of a session in minutes after a user logs in. Default is 60. Maximum value is 1,440.
 * @property subjectKey Custom SAML attribute to use for user names. Default is an empty string - `""`. This will cause Elasticsearch to use the `NameID` element of the `Subject`, which is the default location for name identifiers in the SAML specification.
 */
public data class DomainSamlOptionsSamlOptionsArgs(
    public val enabled: Output<Boolean>? = null,
    public val idp: Output<DomainSamlOptionsSamlOptionsIdpArgs>? = null,
    public val masterBackendRole: Output<String>? = null,
    public val masterUserName: Output<String>? = null,
    public val rolesKey: Output<String>? = null,
    public val sessionTimeoutMinutes: Output<Int>? = null,
    public val subjectKey: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.elasticsearch.inputs.DomainSamlOptionsSamlOptionsArgs> {
    override fun toJava(): com.pulumi.aws.elasticsearch.inputs.DomainSamlOptionsSamlOptionsArgs =
        com.pulumi.aws.elasticsearch.inputs.DomainSamlOptionsSamlOptionsArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .idp(idp?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .masterBackendRole(masterBackendRole?.applyValue({ args0 -> args0 }))
            .masterUserName(masterUserName?.applyValue({ args0 -> args0 }))
            .rolesKey(rolesKey?.applyValue({ args0 -> args0 }))
            .sessionTimeoutMinutes(sessionTimeoutMinutes?.applyValue({ args0 -> args0 }))
            .subjectKey(subjectKey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DomainSamlOptionsSamlOptionsArgs].
 */
@PulumiTagMarker
public class DomainSamlOptionsSamlOptionsArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var idp: Output<DomainSamlOptionsSamlOptionsIdpArgs>? = null

    private var masterBackendRole: Output<String>? = null

    private var masterUserName: Output<String>? = null

    private var rolesKey: Output<String>? = null

    private var sessionTimeoutMinutes: Output<Int>? = null

    private var subjectKey: Output<String>? = null

    /**
     * @param value Whether SAML authentication is enabled.
     */
    @JvmName("gmetopgolgavomrm")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Information from your identity provider.
     */
    @JvmName("mxlnjablxbhsquhr")
    public suspend fun idp(`value`: Output<DomainSamlOptionsSamlOptionsIdpArgs>) {
        this.idp = value
    }

    /**
     * @param value This backend role from the SAML IdP receives full permissions to the cluster, equivalent to a new master user.
     */
    @JvmName("jjqvaklsjnvoexod")
    public suspend fun masterBackendRole(`value`: Output<String>) {
        this.masterBackendRole = value
    }

    /**
     * @param value This username from the SAML IdP receives full permissions to the cluster, equivalent to a new master user.
     */
    @JvmName("mkfdtvvddvwntqjh")
    public suspend fun masterUserName(`value`: Output<String>) {
        this.masterUserName = value
    }

    /**
     * @param value Element of the SAML assertion to use for backend roles. Default is roles.
     */
    @JvmName("givvdcbrudthfiyi")
    public suspend fun rolesKey(`value`: Output<String>) {
        this.rolesKey = value
    }

    /**
     * @param value Duration of a session in minutes after a user logs in. Default is 60. Maximum value is 1,440.
     */
    @JvmName("lmimkjicnmriwllv")
    public suspend fun sessionTimeoutMinutes(`value`: Output<Int>) {
        this.sessionTimeoutMinutes = value
    }

    /**
     * @param value Custom SAML attribute to use for user names. Default is an empty string - `""`. This will cause Elasticsearch to use the `NameID` element of the `Subject`, which is the default location for name identifiers in the SAML specification.
     */
    @JvmName("spmcejavgkohopkw")
    public suspend fun subjectKey(`value`: Output<String>) {
        this.subjectKey = value
    }

    /**
     * @param value Whether SAML authentication is enabled.
     */
    @JvmName("oleawrtjvbpfappn")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Information from your identity provider.
     */
    @JvmName("wmysksqhginavccb")
    public suspend fun idp(`value`: DomainSamlOptionsSamlOptionsIdpArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.idp = mapped
    }

    /**
     * @param argument Information from your identity provider.
     */
    @JvmName("bgxupxwhromnllhf")
    public suspend fun idp(argument: suspend DomainSamlOptionsSamlOptionsIdpArgsBuilder.() -> Unit) {
        val toBeMapped = DomainSamlOptionsSamlOptionsIdpArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.idp = mapped
    }

    /**
     * @param value This backend role from the SAML IdP receives full permissions to the cluster, equivalent to a new master user.
     */
    @JvmName("omxlsnpelbpndnil")
    public suspend fun masterBackendRole(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.masterBackendRole = mapped
    }

    /**
     * @param value This username from the SAML IdP receives full permissions to the cluster, equivalent to a new master user.
     */
    @JvmName("utrwlhlitvhhxgdx")
    public suspend fun masterUserName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.masterUserName = mapped
    }

    /**
     * @param value Element of the SAML assertion to use for backend roles. Default is roles.
     */
    @JvmName("dgalxqrysrblabrk")
    public suspend fun rolesKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rolesKey = mapped
    }

    /**
     * @param value Duration of a session in minutes after a user logs in. Default is 60. Maximum value is 1,440.
     */
    @JvmName("jwtctldvwstiwnic")
    public suspend fun sessionTimeoutMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sessionTimeoutMinutes = mapped
    }

    /**
     * @param value Custom SAML attribute to use for user names. Default is an empty string - `""`. This will cause Elasticsearch to use the `NameID` element of the `Subject`, which is the default location for name identifiers in the SAML specification.
     */
    @JvmName("ujdwlbojoxcsoerf")
    public suspend fun subjectKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subjectKey = mapped
    }

    internal fun build(): DomainSamlOptionsSamlOptionsArgs = DomainSamlOptionsSamlOptionsArgs(
        enabled = enabled,
        idp = idp,
        masterBackendRole = masterBackendRole,
        masterUserName = masterUserName,
        rolesKey = rolesKey,
        sessionTimeoutMinutes = sessionTimeoutMinutes,
        subjectKey = subjectKey,
    )
}
